// Never forget to include std.mi
#include "std.mi"

//Declare local functions for use in script
Function initVol();
Function updateVol(int x, int y);
Function setVolPosition(int p);

//Declare global variables for use in script
Global AnimatedLayer Vol;
Global Map volMap;
Global Text VolText;
Global Slider HiddenVol;
Global Int VolChanging, VolFrames, LastVol;

//When the script is loaded, do this
System.onScriptLoaded() {

	// Get the group that has the objects we want
	Group vGroup = getScriptGroup();

	// Now that we have the group, get the objects in the group
	Vol = vGroup.findObject("VolAnim");
	HiddenVol = vGroup.findObject("HiddenVol");
	VolText = vGroup.findObject("vollvl");

	// Load the gradient map
	volMap = new Map;
	volMap.loadMap("player.Map.Vol");

	// Intialize variables
	LastVol = 0;
	VolChanging = 0;
	VolFrames = Vol.getLength();
	VolFrames = VolFrames - 1;

	initVol();
}

initVol(){
  int v = HiddenVol.getPosition();
  setVolPosition(v);
  int p = v * (100 / 255) + 1;
  VolText.setText(System.integerToString(p));
}

// Reads clicks on seeker
Vol.onLeftButtonDown(int x, int y) {
	if (getVolume() > 0) {
		VolChanging = 1;
		updateVol(x, y);
	}
}

Vol.onLeftButtonUp(int x, int y) {
	Float l;
	if (VolChanging) {
		updateVol(x,y);
		VolChanging = 0;
	}
}

// Reads mouse movement of seeker
Vol.onMouseMove(int x, int y) {
	if (VolChanging) {
		updateVol(x, y);
	}
}

// Updates seeker
updateVol(int x, int y) {
	int v = volMap.getValue(x - Vol.getLeft(), y - Vol.getTop());
	if (v > 0) {
		setVolPosition(v);
		if (System.getVolume() >= 0) {
			int p = v * (100 / 255) + 1;
			System.setVolume(v);
			VolText.setText(System.integerToString(p));
		}
	}
}

// Moves seeker frame position
setVolPosition(int p) {
	int f = (p * VolFrames) / 255;
  if (p > 0) {
		Vol.gotoFrame(f + 1);
	}
	if (p == 0) {
		Vol.gotoFrame(0);
	}
}

// Reads system position changes
HiddenVol.onPostedPosition(int p) {
	if (p != LastVol && !VolChanging) {
		setVolPosition(p);
		LastVol = p;
	}
}

System.onScriptUnloading() {
	delete volMap;
}